@@ -4,8 +4,8 @@
 # Contributed by Ben Elliston <bje@gnu.org>.
 #
 # This test reads pairs from config-sub.data: an alias and its
-# canonical triplet.  The config.sub scripts is invoked and the test
-# checks that the alias expands to the expected canonical triplet.
+# canonical triplet.  config.sub is invoked and the test checks that
+# the alias expands to the expected canonical triplet.
 
 verbose=false
 
@@ -25,7 +25,8 @@ run_config_sub ()
 }
 
 if run_config_sub ; then
-    $verbose || echo "PASS: config.sub checks"
+    numtests=$(wc -l config-sub.data | cut -d' ' -f1)
+    $verbose || echo "PASS: config.sub checks ($numtests tests)"
 else
     exit 1
 fi
